aboutsummaryrefslogtreecommitdiff
path: root/src/testing
diff options
context:
space:
mode:
Diffstat (limited to 'src/testing')
-rwxr-xr-xsrc/testing/initialize_taler_system.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/testing/initialize_taler_system.sh b/src/testing/initialize_taler_system.sh
index b4cbbb26..d78ad1bf 100755
--- a/src/testing/initialize_taler_system.sh
+++ b/src/testing/initialize_taler_system.sh
@@ -148,11 +148,11 @@ taler-exchange-httpd --version
taler-merchant-httpd --version
libeufin-cli --version
# euFin before the exchange, because must set
# the PAYTO_URI config option (with unguessable IBAN)
# before the exchange starts.
-echo "Setting up euFin ..."
-# reset eufin database
+echo "Setting up libeufin ..."
+# reset libeufin database
rm -f $TALER_DB
taler-bank-manage-testing $NEXUS_PORT $TALER_DB $EXCHANGE_URL $CONF
echo -n "Setting up exchange ..."
@@ -148,11 +148,11 @@ taler-exchange-httpd --version
taler-merchant-httpd --version
libeufin-cli --version
-# euFin before the exchange, because must set
+# Setup libeuFin before the exchange, because we must set
# the PAYTO_URI config option (with unguessable IBAN)
# before the exchange starts.